@@ -357,6 +357,17 @@ namespace configmaps {
     throw wrongTypeExp;
   }
 
+  ConfigItem::operator ConfigMap& () const {
+    if(!item) {
+      fprintf(stderr, "(map&) parent: %s\n", parentName.c_str());
+      throw wrongTypeExp;
+    }
+    ConfigMap *m = dynamic_cast<ConfigMap*>(item);
+    if(m) return *m;
+    fprintf(stderr, "(map&) parent: %s\n", parentName.c_str());
+    throw wrongTypeExp;
+  }
+
   ConfigItem::operator ConfigMap* () {
     if(!item) {
       item = new ConfigMap();
@@ -368,6 +379,17 @@ namespace configmaps {
     throw wrongTypeExp;
   }
 
+  ConfigItem::operator ConfigMap* () const {
+    if(!item) {
+      fprintf(stderr, "(map&) parent: %s\n", parentName.c_str());
+      throw wrongTypeExp;
+    }
+    ConfigMap *m = dynamic_cast<ConfigMap*>(item);
+    if(m) return m;
+    fprintf(stderr, "(map*) parent: %s\n", parentName.c_str());
+    throw wrongTypeExp;
+  }
+
   ConfigItem::operator ConfigVector& () {
     return *getOrCreateVector();
   }
